@@ -36,6 +36,7 @@ from .globals import (
     BPSRATES,
     READONLY,
     UBX_CFGPRT,
+    CONNECTED,
 )
 from .strings import LBLCFGPRT
 
@@ -188,7 +189,7 @@ class UBX_PORT_Frame(Frame):
         Reset panel to initial settings
         """
 
-        if self.__app.serial_handler.connected:
+        if self.__app.conn_status == CONNECTED:
             self._do_poll_prt()
 
     def update_status(self, cfgtype, **kwargs):
